@@ -38,7 +38,7 @@ void mzip_restricted2_updateRP_beta(int *p_adj,
     double logR, choice, sumG;
     double logLH, logLH_prop, logPrior, logPrior_prop, logProp_new, logProp;
     double sumGam;
-    double p_add, p_del, p_swap;
+    double p_add, p_del;
     double tempB, tempB_prop, xbeta, xbeta_prop;
     
     int u, i, j, jj, k, l, m, ii, kk, kkk, lInx, count, count_rev, move, putInx;
@@ -51,7 +51,6 @@ void mzip_restricted2_updateRP_beta(int *p_adj,
     
     p_add = (double) 1/3;
     p_del = (double) 1/3;
-    p_swap = 1-(p_add+p_del);
     
     gsl_matrix *gamma_prop = gsl_matrix_calloc(p, q);
     gsl_matrix *B_prop = gsl_matrix_calloc(p, q);
@@ -276,7 +275,7 @@ void mzip_restricted2_updateRP_beta(int *p_adj,
             logPrior += log(gsl_vector_get(omega_beta, m)) + log(1-gsl_vector_get(omega_beta, l));
             
             logProp_new = dnorm(beta_prop, gsl_matrix_get(updateNonzB, l, jj), sqrt(beta_prop_var), 1);
-            logProp = dnorm(gsl_matrix_get(updateNonzB, l, jj), beta_prop, sqrt(beta_prop_var), 1);
+            logProp = dnorm(gsl_matrix_get(updateNonzB, m, jj), beta_prop, sqrt(beta_prop_var), 1);
             
         }
         
@@ -508,7 +507,7 @@ void mzip_restricted2_updateRP_alpha(int *p_adj,
     double logR, choice, sumG;
     double logLH, logLH_prop, logPrior, logPrior_prop, logProp_new, logProp;
     double sumGam;
-    double p_add, p_del, p_swap;
+    double p_add, p_del;
     double scale;
     
     int u, i, j, jj, k, l, m, ii, kk, kkk, lInx, count, count_rev, move, putInx;
@@ -521,7 +520,6 @@ void mzip_restricted2_updateRP_alpha(int *p_adj,
     
     p_add = (double) 1/3;
     p_del = (double) 1/3;
-    p_swap = 1-(p_add+p_del);
     
     gsl_matrix *gamma_prop = gsl_matrix_calloc(p, q);
     gsl_matrix *A_prop = gsl_matrix_calloc(p, q);
@@ -749,7 +747,7 @@ void mzip_restricted2_updateRP_alpha(int *p_adj,
             logPrior += log(gsl_vector_get(omega_alpha, m)) + log(1-gsl_vector_get(omega_alpha, l));
             
             logProp_new = dnorm(alpha_prop, gsl_matrix_get(updateNonzA, l, jj), sqrt(alpha_prop_var), 1);
-            logProp = dnorm(gsl_matrix_get(updateNonzA, l, jj), alpha_prop, sqrt(alpha_prop_var), 1);
+            logProp = dnorm(gsl_matrix_get(updateNonzA, m, jj), alpha_prop, sqrt(alpha_prop_var), 1);
             
         }
         
